# File Organizer Pro

A simple Python module to organize files in a directory based on their extensions.

## Installation
```bash
pip install file_organizer_pro

## License
This project is licensed under the MIT License. See the [LICENSE](LICENSE) file for details.